@@ -49,6 +49,12 @@ class USERPREF_HT_header(bpy_types.Header, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -193,6 +199,12 @@ class USERPREF_MT_addons_online_resources(bpy_types.Menu,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -241,7 +253,173 @@ class USERPREF_MT_addons_online_resources(bpy_types.Menu,
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class USERPREF_MT_app_templates(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    preset_subdir = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_ex(self, context, use_splash, use_default, use_install):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -348,6 +526,12 @@ class USERPREF_MT_appconfigs(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -396,7 +580,8 @@ class USERPREF_MT_appconfigs(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -503,6 +688,12 @@ class USERPREF_MT_interaction_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -551,7 +742,8 @@ class USERPREF_MT_interaction_presets(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -665,6 +857,12 @@ class USERPREF_MT_interface_theme_presets(bpy_types.Menu,
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -713,7 +911,8 @@ class USERPREF_MT_interface_theme_presets(bpy_types.Menu,
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -820,6 +1019,12 @@ class USERPREF_MT_keyconfigs(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -868,7 +1073,8 @@ class USERPREF_MT_keyconfigs(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -969,6 +1175,12 @@ class USERPREF_MT_ndof_settings(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1017,7 +1229,8 @@ class USERPREF_MT_ndof_settings(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1118,6 +1331,12 @@ class USERPREF_MT_splash(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1166,7 +1385,8 @@ class USERPREF_MT_splash(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1267,6 +1487,12 @@ class USERPREF_MT_splash_footer(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1315,7 +1541,167 @@ class USERPREF_MT_splash_footer(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def path_menu(self, searchpaths, operator, props_default, filter_ext):
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class USERPREF_MT_templates_splash(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    preset_subdir = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name):
         ''' 
 
         '''
@@ -1419,6 +1805,12 @@ class USERPREF_PT_addons(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1571,6 +1963,12 @@ class USERPREF_PT_edit(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1717,6 +2115,12 @@ class USERPREF_PT_file(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -1869,6 +2273,12 @@ class USERPREF_PT_input(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2015,6 +2425,12 @@ class USERPREF_PT_interface(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2161,6 +2577,12 @@ class USERPREF_PT_system(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2307,6 +2729,12 @@ class USERPREF_PT_tabs(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
@@ -2450,6 +2878,12 @@ class USERPREF_PT_theme(bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_hidden(self):
         ''' 
 
