@@ -52,7 +52,7 @@ def apply_solution_scale(distance: float = 0.0):
 
 
 def bundles_to_mesh():
-    ''' Create vertex cloud using coordinates of reconstructed tracks
+    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py\:281 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$281> _
 
     '''
 
@@ -123,7 +123,7 @@ def clear_track_path(action: typing.Union[str, int] = 'REMAINED',
 
 
 def constraint_to_fcurve():
-    ''' Create F-Curves for object which will copy object's movement caused by this constraint
+    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py\:508 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$508> _
 
     '''
 
@@ -165,7 +165,7 @@ def delete_marker():
 
 
 def delete_proxy():
-    ''' Delete movie clip proxy files from the hard drive
+    ''' Delete movie clip proxy files from the hard drive :file: startup/bl_operators/clip.py\:351 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$351> _
 
     '''
 
@@ -617,7 +617,7 @@ def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
 
 
 def set_active_clip():
-    ''' Undocumented
+    ''' Undocumented :file: startup/bl_operators/clip.py\:215 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$215> _
 
     '''
 
@@ -701,7 +701,7 @@ def set_solver_keyframe(keyframe: typing.Union[str, int] = 'KEYFRAME_A'):
 
 
 def set_viewport_background():
-    ''' Set current movie clip as a camera background in 3D view-port (works only when a 3D view-port is visible)
+    ''' Set current movie clip as a camera background in 3D view-port (works only when a 3D view-port is visible) :file: startup/bl_operators/clip.py\:412 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$412> _
 
     '''
 
@@ -709,7 +709,7 @@ def set_viewport_background():
 
 
 def setup_tracking_scene():
-    ''' Prepare scene for compositing 3D objects into this footage
+    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py\:976 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$976> _
 
     '''
 
@@ -831,7 +831,7 @@ def track_markers(backwards: bool = False, sequence: bool = False):
 
 
 def track_settings_as_default():
-    ''' Copy tracking settings from active track to default settings
+    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py\:1013 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$1013> _
 
     '''
 
@@ -839,7 +839,7 @@ def track_settings_as_default():
 
 
 def track_settings_to_track():
-    ''' Copy tracking settings from active track to selected tracks
+    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py\:1061 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$1061> _
 
     '''
 
@@ -847,7 +847,7 @@ def track_settings_to_track():
 
 
 def track_to_empty():
-    ''' Create an Empty object which will be copying movement of active track
+    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py\:257 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/clip.py$257> _
 
     '''
 
