@@ -44,3 +44,11 @@ def undo_push(message: str = "Add an undo step *function may be moved*"):
     '''
 
     pass
+
+
+def undo_redo():
+    ''' Undo and redo previous action
+
+    '''
+
+    pass
