@@ -4,8 +4,8 @@ import typing
 
 def ply(filepath: str = "",
         check_existing: bool = True,
-        axis_forward: typing.Union[int, str] = 'Y',
-        axis_up: typing.Union[int, str] = 'Z',
+        axis_forward: typing.Union[str, int] = 'Y',
+        axis_up: typing.Union[str, int] = 'Z',
         filter_glob: str = "*.ply",
         use_mesh_modifiers: bool = True,
         use_normals: bool = True,
@@ -19,9 +19,9 @@ def ply(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_mesh_modifiers: Apply Modifiers, Apply Modifiers to the exported mesh
@@ -41,15 +41,15 @@ def ply(filepath: str = "",
 
 def stl(filepath: str = "",
         check_existing: bool = True,
-        axis_forward: typing.Union[int, str] = 'Y',
-        axis_up: typing.Union[int, str] = 'Z',
+        axis_forward: typing.Union[str, int] = 'Y',
+        axis_up: typing.Union[str, int] = 'Z',
         filter_glob: str = "*.stl",
         use_selection: bool = False,
         global_scale: float = 1.0,
         use_scene_unit: bool = False,
         ascii: bool = False,
         use_mesh_modifiers: bool = True,
-        batch_mode: typing.Union[int, str] = 'OFF'):
+        batch_mode: typing.Union[str, int] = 'OFF'):
     ''' Save STL triangle mesh data from the active object
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -57,9 +57,9 @@ def stl(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_selection: Selection Only, Export selected objects only
@@ -73,7 +73,7 @@ def stl(filepath: str = "",
     :param use_mesh_modifiers: Apply Modifiers, Apply the modifiers before saving
     :type use_mesh_modifiers: bool
     :param batch_mode: Batch Mode * OFF Off, All data in one file. * OBJECT Object, Each object as a file.
-    :type batch_mode: typing.Union[int, str]
+    :type batch_mode: typing.Union[str, int]
     '''
 
     pass
