@@ -4,8 +4,8 @@ import typing
 
 def autodesk_3ds(filepath: str = "",
                  check_existing: bool = True,
-                 axis_forward: typing.Union[int, str] = 'Y',
-                 axis_up: typing.Union[int, str] = 'Z',
+                 axis_forward: typing.Union[str, int] = 'Y',
+                 axis_up: typing.Union[str, int] = 'Z',
                  filter_glob: str = "*.3ds",
                  use_selection: bool = False):
     ''' Export to 3DS file format (.3ds)
@@ -15,9 +15,9 @@ def autodesk_3ds(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_selection: Selection Only, Export selected objects only
@@ -29,28 +29,30 @@ def autodesk_3ds(filepath: str = "",
 
 def fbx(filepath: str = "",
         check_existing: bool = True,
-        axis_forward: typing.Union[int, str] = '-Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = '-Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.fbx",
-        version: typing.Union[int, str] = 'BIN7400',
-        ui_tab: typing.Union[int, str] = 'MAIN',
+        version: typing.Union[str, int] = 'BIN7400',
+        ui_tab: typing.Union[str, int] = 'MAIN',
         use_selection: bool = False,
         global_scale: float = 1.0,
         apply_unit_scale: bool = True,
+        apply_scale_options: typing.Union[str, int] = 'FBX_SCALE_NONE',
         bake_space_transform: bool = False,
-        object_types: typing.Union[typing.Set[int], typing.Set[str]] = {
+        object_types: typing.Union[typing.Set[str], typing.Set[int]] = {
             'ARMATURE', 'CAMERA', 'EMPTY', 'LAMP', 'MESH', 'OTHER'
         },
         use_mesh_modifiers: bool = True,
-        mesh_smooth_type: typing.Union[int, str] = 'OFF',
+        use_mesh_modifiers_render: bool = True,
+        mesh_smooth_type: typing.Union[str, int] = 'OFF',
         use_mesh_edges: bool = False,
         use_tspace: bool = False,
         use_custom_props: bool = False,
         add_leaf_bones: bool = True,
-        primary_bone_axis: typing.Union[int, str] = 'Y',
-        secondary_bone_axis: typing.Union[int, str] = 'X',
+        primary_bone_axis: typing.Union[str, int] = 'Y',
+        secondary_bone_axis: typing.Union[str, int] = 'X',
         use_armature_deform_only: bool = False,
-        armature_nodetype: typing.Union[int, str] = 'NULL',
+        armature_nodetype: typing.Union[str, int] = 'NULL',
         bake_anim: bool = True,
         bake_anim_use_all_bones: bool = True,
         bake_anim_use_nla_strips: bool = True,
@@ -63,9 +65,9 @@ def fbx(filepath: str = "",
         use_default_take: bool = True,
         use_anim_optimize: bool = True,
         anim_optimize_precision: float = 6.0,
-        path_mode: typing.Union[int, str] = 'AUTO',
+        path_mode: typing.Union[str, int] = 'AUTO',
         embed_textures: bool = False,
-        batch_mode: typing.Union[int, str] = 'OFF',
+        batch_mode: typing.Union[str, int] = 'OFF',
         use_batch_own_dir: bool = True,
         use_metadata: bool = True):
     ''' Write a FBX file
@@ -75,29 +77,33 @@ def fbx(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param version: Version, Choose which version of the exporter to use * BIN7400 FBX 7.4 binary, Modern 7.4 binary version. * ASCII6100 FBX 6.1 ASCII, Legacy 6.1 ascii version - WARNING: Deprecated and no more maintained.
-    :type version: typing.Union[int, str]
+    :type version: typing.Union[str, int]
     :param ui_tab: ui_tab, Export options categories * MAIN Main, Main basic settings. * GEOMETRY Geometries, Geometry-related settings. * ARMATURE Armatures, Armature-related settings. * ANIMATION Animation, Animation-related settings.
-    :type ui_tab: typing.Union[int, str]
+    :type ui_tab: typing.Union[str, int]
     :param use_selection: Selected Objects, Export selected objects on visible layers
     :type use_selection: bool
     :param global_scale: Scale, Scale all data (Some importers do not support scaled armatures!)
     :type global_scale: float
-    :param apply_unit_scale: Apply Unit, Scale all data according to current Blender size, to match default FBX unit (centimeter, some importers do not handle UnitScaleFactor properly)
+    :param apply_unit_scale: Apply Unit, Take into account current Blender units settings (if unset, raw Blender Units values are used as-is)
     :type apply_unit_scale: bool
+    :param apply_scale_options: Apply Scalings, How to apply custom and units scalings in generated FBX file (Blender uses FBX scale to detect units on import, but many other applications do not handle the same way) * FBX_SCALE_NONE All Local, Apply custom scaling and units scaling to each object transformation, FBX scale remains at 1.0. * FBX_SCALE_UNITS FBX Units Scale, Apply custom scaling to each object transformation, and units scaling to FBX scale. * FBX_SCALE_CUSTOM FBX Custom Scale, Apply custom scaling to FBX scale, and units scaling to each object transformation. * FBX_SCALE_ALL FBX All, Apply custom scaling and units scaling to FBX scale.
+    :type apply_scale_options: typing.Union[str, int]
     :param bake_space_transform: !EXPERIMENTAL! Apply Transform, Bake space transform into object data, avoids getting unwanted rotations to objects when target space is not aligned with Blender's space (WARNING! experimental option, use at own risks, known broken with armatures/animations)
     :type bake_space_transform: bool
     :param object_types: Object Types, Which kind of object to export * EMPTY Empty. * CAMERA Camera. * LAMP Lamp. * ARMATURE Armature, WARNING: not supported in dupli/group instances. * MESH Mesh. * OTHER Other, Other geometry types, like curve, metaball, etc. (converted to meshes).
-    :type object_types: typing.Union[typing.Set[int], typing.Set[str]]
+    :type object_types: typing.Union[typing.Set[str], typing.Set[int]]
     :param use_mesh_modifiers: Apply Modifiers, Apply modifiers to mesh objects (except Armature ones) - WARNING: prevents exporting shape keys
     :type use_mesh_modifiers: bool
+    :param use_mesh_modifiers_render: Use Modifiers Render Setting, Use render settings when applying modifiers to mesh objects
+    :type use_mesh_modifiers_render: bool
     :param mesh_smooth_type: Smoothing, Export smoothing information (prefer 'Normals Only' option if your target importer understand split normals) * OFF Normals Only, Export only normals instead of writing edge or face smoothing data. * FACE Face, Write face smoothing. * EDGE Edge, Write edge smoothing.
-    :type mesh_smooth_type: typing.Union[int, str]
+    :type mesh_smooth_type: typing.Union[str, int]
     :param use_mesh_edges: Loose Edges, Export loose edges (as two-vertices polygons)
     :type use_mesh_edges: bool
     :param use_tspace: Tangent Space, Add binormal and tangent vectors, together with normal they form the tangent space (will only work correctly with tris/quads only meshes!)
@@ -107,13 +113,13 @@ def fbx(filepath: str = "",
     :param add_leaf_bones: Add Leaf Bones, Append a final bone to the end of each chain to specify last bone length (use this when you intend to edit the armature from exported data)
     :type add_leaf_bones: bool
     :param primary_bone_axis: Primary Bone Axis
-    :type primary_bone_axis: typing.Union[int, str]
+    :type primary_bone_axis: typing.Union[str, int]
     :param secondary_bone_axis: Secondary Bone Axis
-    :type secondary_bone_axis: typing.Union[int, str]
+    :type secondary_bone_axis: typing.Union[str, int]
     :param use_armature_deform_only: Only Deform Bones, Only write deforming bones (and non-deforming ones when they have deforming children)
     :type use_armature_deform_only: bool
     :param armature_nodetype: Armature FBXNode Type, FBX type of node (object) used to represent Blender's armatures (use Null one unless you experience issues with other app, other choices may no import back perfectly in Blender...) * NULL Null, 'Null' FBX node, similar to Blender's Empty (default). * ROOT Root, 'Root' FBX node, supposed to be the root of chains of bones.... * LIMBNODE LimbNode, 'LimbNode' FBX node, a regular joint between two bones....
-    :type armature_nodetype: typing.Union[int, str]
+    :type armature_nodetype: typing.Union[str, int]
     :param bake_anim: Baked Animation, Export baked keyframe animation
     :type bake_anim: bool
     :param bake_anim_use_all_bones: Key All Bones, Force exporting at least one key of animation for all bones (needed with some target applications, like UE4)
@@ -139,11 +145,11 @@ def fbx(filepath: str = "",
     :param anim_optimize_precision: Precision, Tolerance for comparing double keyframes (higher for greater accuracy)
     :type anim_optimize_precision: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[int, str]
+    :type path_mode: typing.Union[str, int]
     :param embed_textures: Embed Textures, Embed textures in FBX binary file (only for "Copy" path mode!)
     :type embed_textures: bool
     :param batch_mode: Batch Mode * OFF Off, Active scene to file. * SCENE Scene, Each scene as a file. * GROUP Group, Each group as a file.
-    :type batch_mode: typing.Union[int, str]
+    :type batch_mode: typing.Union[str, int]
     :param use_batch_own_dir: Batch Own Dir, Create a dir for each exported file
     :type use_batch_own_dir: bool
     :param use_metadata: Use Metadata
@@ -155,12 +161,13 @@ def fbx(filepath: str = "",
 
 def obj(filepath: str = "",
         check_existing: bool = True,
-        axis_forward: typing.Union[int, str] = '-Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = '-Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.obj;*.mtl",
         use_selection: bool = False,
         use_animation: bool = False,
         use_mesh_modifiers: bool = True,
+        use_mesh_modifiers_render: bool = False,
         use_edges: bool = True,
         use_smooth_groups: bool = False,
         use_smooth_groups_bitflags: bool = False,
@@ -175,7 +182,7 @@ def obj(filepath: str = "",
         group_by_material: bool = False,
         keep_vertex_order: bool = False,
         global_scale: float = 1.0,
-        path_mode: typing.Union[int, str] = 'AUTO'):
+        path_mode: typing.Union[str, int] = 'AUTO'):
     ''' Save a Wavefront OBJ File
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -183,17 +190,19 @@ def obj(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_selection: Selection Only, Export selected objects only
     :type use_selection: bool
     :param use_animation: Animation, Write out an OBJ for each frame
     :type use_animation: bool
-    :param use_mesh_modifiers: Apply Modifiers, Apply modifiers (preview resolution)
+    :param use_mesh_modifiers: Apply Modifiers, Apply modifiers
     :type use_mesh_modifiers: bool
+    :param use_mesh_modifiers_render: Use Modifiers Render Settings, Use render settings when applying modifiers to mesh objects
+    :type use_mesh_modifiers_render: bool
     :param use_edges: Include Edges
     :type use_edges: bool
     :param use_smooth_groups: Smooth Groups, Write sharp edges as smooth groups
@@ -223,7 +232,7 @@ def obj(filepath: str = "",
     :param global_scale: Scale
     :type global_scale: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[int, str]
+    :type path_mode: typing.Union[str, int]
     '''
 
     pass
@@ -231,8 +240,8 @@ def obj(filepath: str = "",
 
 def x3d(filepath: str = "",
         check_existing: bool = True,
-        axis_forward: typing.Union[int, str] = 'Z',
-        axis_up: typing.Union[int, str] = 'Y',
+        axis_forward: typing.Union[str, int] = 'Z',
+        axis_up: typing.Union[str, int] = 'Y',
         filter_glob: str = "*.x3d",
         use_selection: bool = False,
         use_mesh_modifiers: bool = True,
@@ -243,7 +252,7 @@ def x3d(filepath: str = "",
         name_decorations: bool = True,
         use_h3d: bool = False,
         global_scale: float = 1.0,
-        path_mode: typing.Union[int, str] = 'AUTO'):
+        path_mode: typing.Union[str, int] = 'AUTO'):
     ''' Export selection to Extensible 3D file (.x3d)
 
     :param filepath: File Path, Filepath used for exporting the file
@@ -251,9 +260,9 @@ def x3d(filepath: str = "",
     :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
     :param axis_forward: Forward
-    :type axis_forward: typing.Union[int, str]
+    :type axis_forward: typing.Union[str, int]
     :param axis_up: Up
-    :type axis_up: typing.Union[int, str]
+    :type axis_up: typing.Union[str, int]
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param use_selection: Selection Only, Export selected objects only
@@ -275,7 +284,7 @@ def x3d(filepath: str = "",
     :param global_scale: Scale
     :type global_scale: float
     :param path_mode: Path Mode, Method used to reference paths * AUTO Auto, Use Relative paths with subdirectories only. * ABSOLUTE Absolute, Always write absolute paths. * RELATIVE Relative, Always write relative paths (where possible). * MATCH Match, Match Absolute/Relative setting with input path. * STRIP Strip Path, Filename only. * COPY Copy, Copy the file to the destination path (or subdirectory).
-    :type path_mode: typing.Union[int, str]
+    :type path_mode: typing.Union[str, int]
     '''
 
     pass
