@@ -19,8 +19,18 @@ def active_frames_delete_all():
     pass
 
 
+def blank_frame_add(all_layers: bool = False):
+    ''' Insert a blank frame on the current frame (all subsequently existing frames, if any, are shifted right by one frame)
+
+    :param all_layers: All Layers, Create blank frame in all layers, not only active
+    :type all_layers: bool
+    '''
+
+    pass
+
+
 def brush_add():
-    ''' Add new Grease Pencil drawing brush for the active Grease Pencil datablock
+    ''' Add new Grease Pencil drawing brush for the active Grease Pencil data-block
 
     '''
 
@@ -55,14 +65,14 @@ def brush_move(type: typing.Union[str, int] = 'UP'):
     pass
 
 
-def brush_paint(stroke: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
-                wait_for_input: bool = True):
+def brush_paint(
+        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                             'bpy_prop_collection'] = None,
+        wait_for_input: bool = True):
     ''' Apply tweaks to strokes by painting over the strokes
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Enter a mini 'sculpt-mode' if enabled, otherwise, exit after drawing a single stroke
     :type wait_for_input: bool
     '''
@@ -151,7 +161,7 @@ def copy():
 
 
 def data_add():
-    ''' Add new Grease Pencil datablock
+    ''' Add new Grease Pencil data-block
 
     '''
 
@@ -159,7 +169,7 @@ def data_add():
 
 
 def data_unlink():
-    ''' Unlink active Grease Pencil datablock
+    ''' Unlink active Grease Pencil data-block
 
     '''
 
@@ -185,17 +195,15 @@ def dissolve():
 
 
 def draw(mode: typing.Union[str, int] = 'DRAW',
-         stroke: typing.
-         Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
-               List['bpy.types.OperatorStrokeElement'],
-               'bpy_prop_collection'] = None,
+         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
+                              'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Grease Pencil strokes.
     :type mode: typing.Union[str, int]
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     '''
@@ -239,8 +247,34 @@ def hide(unselected: bool = False):
     pass
 
 
+def interpolate(shift: float = 0.0):
+    ''' Interpolate grease pencil strokes between frames
+
+    :param shift: Shift, Bias factor for which frame has more influence on the interpolated strokes
+    :type shift: float
+    '''
+
+    pass
+
+
+def interpolate_reverse():
+    ''' Remove breakdown frames generated by interpolating between two Grease Pencil frames
+
+    '''
+
+    pass
+
+
+def interpolate_sequence():
+    ''' Generate 'in-betweens' to smoothly interpolate between Grease Pencil frames
+
+    '''
+
+    pass
+
+
 def layer_add():
-    ''' Add new Grease Pencil layer for the active Grease Pencil datablock
+    ''' Add new Grease Pencil layer for the active Grease Pencil data-block
 
     '''
 
@@ -320,7 +354,7 @@ def move_to_layer(layer: typing.Union[str, int] = 'DEFAULT'):
 
 
 def palette_add():
-    ''' Add new Grease Pencil palette for the active Grease Pencil datablock
+    ''' Add new Grease Pencil palette for the active Grease Pencil data-block
 
     '''
 
@@ -354,7 +388,7 @@ def palette_remove():
 
 
 def palettecolor_add():
-    ''' Add new Grease Pencil palette color for the active Grease Pencil datablock
+    ''' Add new Grease Pencil palette color for the active Grease Pencil data-block
 
     '''
 
@@ -449,9 +483,11 @@ def paste(type: typing.Union[str, int] = 'COPY'):
     pass
 
 
-def reproject():
-    ''' Reproject the selected strokes from the current viewpoint to get all points on the same plane again (e.g. to fix problems from accidental 3D cursor movement, or viewport changes)
+def reproject(type: typing.Union[str, int] = 'PLANAR'):
+    ''' Reproject the selected strokes from the current viewpoint as if they had been newly drawn (e.g. to fix problems from accidental 3D cursor movement or accidental viewport changes, or for matching deforming geometry)
 
+    :param type: Projection Type * PLANAR Planar, Reproject the strokes to end up on the same plane, as if drawn from the current viewpoint using 'Cursor' Stroke Placement. * SURFACE Surface, Reproject the strokes on to the scene geometry, as if drawn using 'Surface' placement.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -563,15 +599,14 @@ def select_grouped(type: typing.Union[str, int] = 'LAYER'):
     pass
 
 
-def select_lasso(path: typing.Union[
-        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
-        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
+                                    'bpy_prop_collection'] = None,
                  deselect: bool = False,
                  extend: bool = True):
     ''' Select Grease Pencil strokes using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param deselect: Deselect, Deselect rather than select items
     :type deselect: bool
     :param extend: Extend, Extend selection instead of deselecting everything first
@@ -716,6 +751,16 @@ def stroke_lock_color():
     pass
 
 
+def stroke_subdivide(number_cuts: int = 1):
+    ''' Subdivide between continuous selected points of the stroke adding a point half way between them
+
+    :param number_cuts: Number of Cuts
+    :type number_cuts: int
+    '''
+
+    pass
+
+
 def unlock_all():
     ''' Unlock all Grease Pencil layers so that they can be edited
 
