@@ -200,7 +200,7 @@ def pack(as_png: bool = False):
 
 
 def project_apply():
-    ''' Project edited image back onto the object
+    ''' Project edited image back onto the object :file: startup/bl_operators/image.py\:230 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/image.py$230> _
 
     '''
 
@@ -208,7 +208,7 @@ def project_apply():
 
 
 def project_edit():
-    ''' Edit a snapshot of the view-port in an external image editor
+    ''' Edit a snapshot of the view-port in an external image editor :file: startup/bl_operators/image.py\:159 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/image.py$159> _
 
     '''
 
@@ -437,7 +437,7 @@ def save_as(save_as_render: bool = False,
 
 
 def save_dirty():
-    ''' Save all modified textures
+    ''' Save all modified textures :file: startup/bl_operators/image.py\:124 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/image.py$124> _
 
     '''
 
