@@ -1302,8 +1302,8 @@ def primitive_plane_add(
 
 
 def primitive_torus_add(
-        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         view_align: bool = False,
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         layers: typing.List[bool] = (False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False, False, False, False, False,
@@ -1319,10 +1319,10 @@ def primitive_torus_add(
         generate_uvs: bool = False):
     ''' Add a torus mesh
 
-    :param rotation: Rotation
-    :type rotation: typing.List[float]
     :param view_align: Align to View
     :type view_align: bool
+    :param rotation: Rotation
+    :type rotation: typing.List[float]
     :param layers: Layers
     :type layers: typing.List[bool]
     :param location: Location
@@ -1669,7 +1669,7 @@ def select_more(use_face_step: bool = True):
 
 
 def select_next_item():
-    ''' Select the next element (using selection order)
+    ''' Select the next element (using selection order) :file: startup/bl_operators/mesh.py\:166 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/mesh.py$166> _
 
     '''
 
@@ -1716,7 +1716,7 @@ def select_nth(nth: int = 2, skip: int = 1, offset: int = 0):
 
 
 def select_prev_item():
-    ''' Select the previous element (using selection order)
+    ''' Select the previous element (using selection order) :file: startup/bl_operators/mesh.py\:191 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/mesh.py$191> _
 
     '''
 
@@ -1784,7 +1784,7 @@ def separate(type: typing.Union[str, int] = 'SELECTED'):
 
 
 def set_normals_from_faces():
-    ''' Set the custom vertex normals from the selected faces ones
+    ''' Set the custom vertex normals from the selected faces ones :file: startup/bl_operators/mesh.py\:218 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/mesh.py$218> _
 
     '''
 
