@@ -3,20 +3,19 @@ import typing
 import bpy.types
 
 
-def add_and_link_node(
-        type: str = "",
-        settings: typing.Union[typing.List['bpy.types.NodeSetting'],
-                               'bpy_prop_collection'] = None,
-        use_transform: bool = False,
-        link_socket_index: int = 0):
+def add_and_link_node(settings: typing.Union[
+        typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection'] = None,
+                      use_transform: bool = False,
+                      type: str = "",
+                      link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
-    :param type: Node Type, Node type
-    :type type: str
     :param settings: Settings, Settings to be applied on the newly created node
     :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
+    :param type: Node Type, Node type
+    :type type: str
     :param link_socket_index: Link Socket Index, Index of the socket to link
     :type link_socket_index: int
     '''
@@ -104,18 +103,18 @@ def add_mask(name: str = "Mask"):
     pass
 
 
-def add_node(type: str = "",
-             settings: typing.Union[typing.List['bpy.types.NodeSetting'],
+def add_node(settings: typing.Union[typing.List['bpy.types.NodeSetting'],
                                     'bpy_prop_collection'] = None,
-             use_transform: bool = False):
+             use_transform: bool = False,
+             type: str = ""):
     ''' Add a node to the active tree
 
-    :param type: Node Type, Node type
-    :type type: str
     :param settings: Settings, Settings to be applied on the newly created node
     :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
+    :param type: Node Type, Node type
+    :type type: str
     '''
 
     pass
@@ -135,19 +134,19 @@ def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def add_search(type: str = "",
-               settings: typing.Union[typing.List['bpy.types.NodeSetting'],
+def add_search(settings: typing.Union[typing.List['bpy.types.NodeSetting'],
                                       'bpy_prop_collection'] = None,
                use_transform: bool = False,
+               type: str = "",
                node_item: typing.Union[str, int] = ''):
     ''' Add a node to the active tree
 
-    :param type: Node Type, Node type
-    :type type: str
     :param settings: Settings, Settings to be applied on the newly created node
     :type settings: typing.Union[typing.List['bpy.types.NodeSetting'], 'bpy_prop_collection']
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
+    :param type: Node Type, Node type
+    :type type: str
     :param node_item: Node Type, Node type
     :type node_item: typing.Union[str, int]
     '''
@@ -222,7 +221,7 @@ def clipboard_paste():
 
 
 def collapse_hide_unused_toggle():
-    ''' Toggle collapsed nodes and hide unused sockets
+    ''' Toggle collapsed nodes and hide unused sockets :file: startup/bl_operators/node.py\:262 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/node.py$262> _
 
     '''
 
@@ -777,7 +776,7 @@ def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
 
 
 def tree_path_parent():
-    ''' Go to parent node tree
+    ''' Go to parent node tree :file: startup/bl_operators/node.py\:292 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/node.py$292> _
 
     '''
 
