@@ -104,7 +104,7 @@ def copy():
 
 
 def crossfade_sounds():
-    ''' Do cross-fading volume animation of two selected sound strips
+    ''' Do cross-fading volume animation of two selected sound strips :file: startup/bl_operators/sequencer.py\:41 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/sequencer.py$41> _
 
     '''
 
@@ -138,7 +138,7 @@ def cut_multicam(camera: int = 1):
 
 
 def deinterlace_selected_movies():
-    ''' Deinterlace all selected movie sources
+    ''' Deinterlace all selected movie sources :file: startup/bl_operators/sequencer.py\:131 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/sequencer.py$131> _
 
     '''
 
