@@ -35,7 +35,7 @@ def mixdown(filepath: str = "",
             format: typing.Union[str, int] = 'S16',
             bitrate: int = 192,
             split_channels: bool = False):
-    ''' Mixes the scene's audio to a sound file
+    ''' Mix the scene's audio to a sound file
 
     :param filepath: File Path, Path to file
     :type filepath: str
@@ -251,7 +251,7 @@ def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
 
     :param method: Method, How to unpack
     :type method: typing.Union[str, int]
-    :param id: Sound Name, Sound datablock name to unpack
+    :param id: Sound Name, Sound data-block name to unpack
     :type id: str
     '''
 
