@@ -155,7 +155,7 @@ def dolly(delta: int = 0, mx: int = 0, my: int = 0):
 
 
 def edit_mesh_extrude_individual_move():
-    ''' Extrude individual elements and move
+    ''' Extrude individual elements and move :file: startup/bl_operators/view3d.py\:36 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/view3d.py$36> _
 
     '''
 
@@ -163,7 +163,7 @@ def edit_mesh_extrude_individual_move():
 
 
 def edit_mesh_extrude_move_normal():
-    ''' Extrude and move along normals
+    ''' Extrude and move along normals :file: startup/bl_operators/view3d.py\:106 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/view3d.py$106> _
 
     '''
 
@@ -171,7 +171,7 @@ def edit_mesh_extrude_move_normal():
 
 
 def edit_mesh_extrude_move_shrink_fatten():
-    ''' Extrude and move along individual normals
+    ''' Extrude and move along individual normals :file: startup/bl_operators/view3d.py\:123 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/view3d.py$123> _
 
     '''
 
