@@ -59,7 +59,7 @@ def addon_install(overwrite: bool = True,
 
 
 def addon_refresh():
-    ''' Scan add-on directories for new modules
+    ''' Scan add-on directories for new modules :file: startup/bl_operators/wm.py\:1949 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1949> _
 
     '''
 
@@ -330,7 +330,7 @@ def appconfig_activate(filepath: str = ""):
 
 
 def appconfig_default():
-    ''' Undocumented
+    ''' Undocumented :file: startup/bl_operators/wm.py\:1388 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1388> _
 
     '''
 
@@ -425,7 +425,7 @@ def append(
 
 
 def blenderplayer_start():
-    ''' Launch the blender-player with the current blend-file
+    ''' Launch the blender-player with the current blend-file :file: startup/bl_operators/wm.py\:1494 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1494> _
 
     '''
 
@@ -906,7 +906,7 @@ def context_toggle_enum(data_path: str = "",
 
 
 def copy_prev_settings():
-    ''' Copy settings from previous version
+    ''' Copy settings from previous version :file: startup/bl_operators/wm.py\:1460 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1460> _
 
     '''
 
@@ -1047,7 +1047,7 @@ def keyconfig_preset_add(name: str = "", remove_active: bool = False):
 
 
 def keyconfig_remove():
-    ''' Remove key config
+    ''' Remove key config :file: startup/bl_operators/wm.py\:1773 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1773> _
 
     '''
 
@@ -1055,7 +1055,7 @@ def keyconfig_remove():
 
 
 def keyconfig_test():
-    ''' Test key-config for conflicts
+    ''' Test key-config for conflicts :file: startup/bl_operators/wm.py\:1542 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1542> _
 
     '''
 
@@ -1063,7 +1063,7 @@ def keyconfig_test():
 
 
 def keyitem_add():
-    ''' Add key map item
+    ''' Add key map item :file: startup/bl_operators/wm.py\:1724 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1724> _
 
     '''
 
@@ -1401,7 +1401,7 @@ def open_mainfile(filepath: str = "",
 
 
 def operator_cheat_sheet():
-    ''' List all the Operators in a text-block, useful for scripting
+    ''' List all the Operators in a text-block, useful for scripting :file: startup/bl_operators/wm.py\:1785 <https://developer.blender.org/diffusion/B/browse/master/release/scripts /startup/bl_operators/wm.py$1785> _
 
     '''
 
