@@ -49,6 +49,14 @@ def display_name_from_filepath(name):
     pass
 
 
+def display_name_to_filepath(name):
+    ''' Performs the reverse of display_name using literal versions of characters which aren't supported in a filepath.
+
+    '''
+
+    pass
+
+
 def ensure_ext(filepath, ext: str, case_sensitive: bool = False):
     ''' Return the path with the extension added if it is not already set.
 
