@@ -1,6 +1,5 @@
 import sys
 import typing
-import bpy.types
 
 
 def BoolProperty(name: str = "",
@@ -10,7 +9,7 @@ def BoolProperty(name: str = "",
                  subtype: str = 'NONE',
                  update=None,
                  get=None,
-                 set=None) -> 'bpy.types.BoolProperty':
+                 set=None):
     ''' Returns a new boolean property definition.
 
     :param name: Name used in the user interface.
@@ -37,7 +36,7 @@ def BoolVectorProperty(name: str = "",
                        size: int = 3,
                        update=None,
                        get=None,
-                       set=None) -> typing.List['bpy.types.BoolProperty']:
+                       set=None):
     ''' Returns a new vector boolean property definition.
 
     :param name: Name used in the user interface.
@@ -60,14 +59,13 @@ def BoolVectorProperty(name: str = "",
     pass
 
 
-def CollectionProperty(
-        type=None,
-        name: str = "",
-        description: str = "",
-        options: set = {'ANIMATABLE'}) -> 'bpy.types.CollectionProperty':
+def CollectionProperty(type=None,
+                       name: str = "",
+                       description: str = "",
+                       options: set = {'ANIMATABLE'}):
     ''' Returns a new collection property definition.
 
-    :param type: bpy.types.PropertyGroup .
+    :param type: bpy.types.ID .
     :param name: Name used in the user interface.
     :type name: str
     :param description: Text used for the tooltip and api documentation.
@@ -86,10 +84,10 @@ def EnumProperty(items: typing.List[str],
                  options: set = {'ANIMATABLE'},
                  update=None,
                  get=None,
-                 set=None) -> 'bpy.types.EnumProperty':
+                 set=None):
     ''' Returns a new enumerator property definition.
 
-    :param items: [(identifier, name, description, icon, number), ...] . The first three elements of the tuples are mandatory. :identifier: The identifier is used for Python access. :name: Name for the interace. :description: Used for documentation and tooltips. :icon: An icon string identifier or integer icon value (e.g. returned by bpy.types.UILayout.icon ) :number: Unique value used as the identifier for this item (stored in file data). Use when the identifier may need to change. When an item only contains 4 items they define (identifier, name, description, number) . For dynamic values a callback can be passed which returns a list in the same format as the static list. This function must take 2 arguments (self, context) , **context may be None**. .. warning:: There is a known bug with using a callback, Python must keep a reference to the strings returned or Blender will crash.
+    :param items: [(identifier, name, description, icon, number), ...] . The first three elements of the tuples are mandatory. :identifier: The identifier is used for Python access. :name: Name for the interace. :description: Used for documentation and tooltips. :icon: An icon string identifier or integer icon value (e.g. returned by bpy.types.UILayout.icon ) :number: Unique value used as the identifier for this item (stored in file data). Use when the identifier may need to change. If the *ENUM_FLAG* option is used, the values are bitmasks and should be powers of two. When an item only contains 4 items they define (identifier, name, description, number) . For dynamic values a callback can be passed which returns a list in the same format as the static list. This function must take 2 arguments (self, context) , **context may be None**. .. warning:: There is a known bug with using a callback, Python must keep a reference to the strings returned or Blender will misbehave or even crash.
     :type items: typing.List[str]
     :param name: Name used in the user interface.
     :type name: str
@@ -121,7 +119,7 @@ def FloatProperty(name: str = "",
                   unit: str = 'NONE',
                   update=None,
                   get=None,
-                  set=None) -> 'bpy.types.FloatProperty':
+                  set=None):
     ''' Returns a new float property definition.
 
     :param name: Name used in the user interface.
@@ -169,7 +167,7 @@ def FloatVectorProperty(name: str = "",
                         size: int = 3,
                         update=None,
                         get=None,
-                        set=None) -> typing.List['bpy.types.FloatProperty']:
+                        set=None):
     ''' Returns a new vector float property definition.
 
     :param name: Name used in the user interface.
@@ -218,7 +216,7 @@ def IntProperty(name: str = "",
                 subtype: str = 'NONE',
                 update=None,
                 get=None,
-                set=None) -> 'bpy.types.IntProperty':
+                set=None):
     ''' Returns a new int property definition.
 
     :param name: Name used in the user interface.
@@ -260,7 +258,7 @@ def IntVectorProperty(name: str = "",
                       size: int = 3,
                       update=None,
                       get=None,
-                      set=None) -> typing.List['bpy.types.IntProperty']:
+                      set=None):
     ''' Returns a new vector int property definition.
 
     :param name: Name used in the user interface.
@@ -297,16 +295,18 @@ def PointerProperty(type=None,
                     name: str = "",
                     description: str = "",
                     options: set = {'ANIMATABLE'},
-                    update=None) -> 'bpy.types.PointerProperty':
+                    poll=None,
+                    update=None):
     ''' Returns a new pointer property definition.
 
-    :param type: bpy.types.PropertyGroup .
+    :param type: bpy.types.ID .
     :param name: Name used in the user interface.
     :type name: str
     :param description: Text used for the tooltip and api documentation.
     :type description: str
     :param options: Enumerator in ['HIDDEN', 'SKIP_SAVE', 'ANIMATABLE', 'LIBRARY_EDITABLE', 'PROPORTIONAL','TEXTEDIT_UPDATE'].
     :type options: set
+    :param poll: function to be called to determine whether an item is valid for this property. The function must take 2 values (self, object) and return Bool.
     :param update: Function to be called when this value is modified, This function must take 2 values (self, context) and return None. *Warning* there are no safety checks to avoid infinite recursion.
     '''
 
@@ -332,7 +332,7 @@ def StringProperty(name: str = "",
                    subtype: str = 'NONE',
                    update=None,
                    get=None,
-                   set=None) -> 'bpy.types.StringProperty':
+                   set=None):
     ''' Returns a new string property definition.
 
     :param name: Name used in the user interface.
