@@ -1,7 +1,7 @@
 import sys
 import typing
-from . import units
 from . import previews
+from . import units
 
 
 def app_template_paths(subdir: str = None):
@@ -127,7 +127,7 @@ def refresh_script_paths():
 
 
 def register_class(cls):
-    ''' Register a subclass of a blender type in ( bpy.types.Panel ,
+    ''' Register a subclass of a blender type in ( bpy.types.Panel , bpy.types.UIList , bpy.types.Menu , bpy.types.Header , bpy.types.Operator , bpy.types.KeyingSetInfo , bpy.types.RenderEngine ). If the class has a *register* class method it will be called before registration.
 
     '''
 
@@ -226,11 +226,11 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
     pass
 
 
-def smpte_from_seconds(time: typing.Union[int, float], fps=None) -> str:
+def smpte_from_seconds(time: typing.Union[float, int], fps=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If the *fps* is not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[int, float]
+    :type time: typing.Union[float, int]
     :return: the frame string.
     '''
 
