@@ -482,7 +482,7 @@ class TipRemoverShader:
 
 
 class py2DCurvatureColorShader:
-    ''' Assigns a color (greyscale) to the stroke based on the curvature. A higher curvature will yield a brighter color.
+    ''' Assigns a color (grayscale) to the stroke based on the curvature. A higher curvature will yield a brighter color.
     '''
 
     def shade(self, stroke):
@@ -836,7 +836,7 @@ class pyTVertexThickenerShader:
 
 
 class pyTimeColorShader:
-    ''' Assigns a greyscale value that increases for every vertex. The brightness will increase along the stroke.
+    ''' Assigns a grayscale value that increases for every vertex. The brightness will increase along the stroke.
     '''
 
     def shade(self, stroke):
